import {httpApi} from "../../request/httpApi";

export default {
    //获取当前合同段的划分树
    async queryWbsTreeData(form) {
        return httpApi({
            url: '/api/blade-manager/wbsTreeContract/lazyQueryContractWbsTree',
            method: 'get',
            params: form
        });
    },
    //查询当前节点下所有元素表信息
    async searchNodeAllTable(form) {
        return httpApi({
            url: '/api/blade-manager/wbsTreeContract/search-node-tables',
            method: 'get',
            params: form,
        })
    },
    //查询节点状态
    async queryNodeStatus(form) {
        return httpApi({
            url: '/api/blade-business/informationWriteQuery/queryNodeStatus',
            method: 'post',
            params: form,
        })
    },
    //查询监理节点状态
    async queryNodeStatusJl(form) {
        return httpApi({
            url: '/api/blade-business/informationWriteQuery/queryNodeStatus-jl',
            method: 'post',
            params: form,
        })
    },
    //复制本表
    async copeBussTab(form) {
        return httpApi({
            url: '/api/blade-manager/exceltab/cope-buss-tab',
            method: 'get',
            params: form,
        })
    },
    //删除本表
    async removeBussTabInfo(form) {
        return httpApi({
            url: '/api/blade-manager/exceltab/remove-buss-tabInfo',
            method: 'post',
            params: form,
        })
    },
    //显示隐藏表单
    async showBussTab(form) {
        return httpApi({
            url: '/api/blade-manager/exceltab/show-buss-tab',
            method: 'get',
            params: form,
        })
    },
    //撤回上报
    async abolishOne(form) {
        return httpApi({
            url: '/api/blade-business/informationWriteQuery/abolishOne',
            method: 'post',
            params: form,
        })
    },
    //单表pdf预览
    async getBussPdfInfo(form) {
        return httpApi({
            url: '/api/blade-manager/exceltab/get-buss-pdfInfo',
            method: 'get',
            params: form,
        })
    },
    //多表预览
    async getBussPdfs(form) {
        return httpApi({
            url: '/api/blade-manager/exceltab/get-buss-pdfs',
            method: 'get',
            params: form,
        })
    },
    //填报页面数据保存
    async saveExcelBussData(form) {
        return httpApi({
            url: '/api/blade-manager/exceltab/save_buss_data',
            method: 'post',
            data: form,
        })
    },
    //获取附件列表
    async getBussFileList(form) {
        return httpApi({
            url: '/api/blade-manager/tablefile/get-buss-fileList',
            method: 'get',
            params: form,
        })
    },
    //逻辑删除
    async removeBussFile(form) {
        return httpApi({
            url: '/api/blade-manager/tablefile/remove',
            method: 'post',
            params: form,
        })
    },
    //获取文件题名
    async queryDocumentTitle(form) {
        return httpApi({
            url: '/api/blade-business/informationWriteQuery/queryDocumentTitle',
            method: 'get',
            params: form,
        })
    },
}
